@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import List
+from typing import List, Literal, Mapping, NewType, Union
 
 from pydantic import BaseModel, Field
 
@@ -15,8 +15,11 @@ class AttributeType(str, Enum):
     UNKNOWN = "crystal.topics.data.attribute-types.unknown"
 
 
+AttributeUid = NewType("AttributeUid", str)
+
+
 class Attribute(BaseModel):
-    uid: str
+    uid: AttributeUid
     type: AttributeType  # noqa: A003
     filterable: bool
     sortable: bool
@@ -26,6 +29,15 @@ class AttributesSchema(BaseModel):
     attributes: List[Attribute] = Field(default=list())
 
 
+CollectionUid = NewType("CollectionUid", str)
+
+
 class Collection(BaseModel):
-    uid: str
+    uid: CollectionUid
     attributes_schema: AttributesSchema
+
+
+AttributeFilter = Union[Literal["*"], List[AttributeUid]]
+
+
+CollectionFilter = Mapping[CollectionUid, AttributeFilter]
