@@ -1,10 +1,10 @@
 import abc
-import uuid
+import hashlib
 from enum import Enum
 from typing import Any, Optional, Union
-from typing_extensions import Literal
 
 from pydantic import BaseModel, PrivateAttr, validator
+from typing_extensions import Literal
 
 from igenius_adapters_sdk.entities import attribute, numeric_binning, uri
 
@@ -28,7 +28,7 @@ class AliasableAttribute(BaseModel):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         object.__setattr__(self, "_original_alias", self.alias)
-        object.__setattr__(self, "_shortened_alias", str(uuid.uuid4()))
+        object.__setattr__(self, "_shortened_alias", str(hashlib.md5(self.alias.encode("utf-8")).hexdigest()))
 
     def switch_to_shortened_alias(self):
         self.alias = self._shortened_alias
