@@ -39,25 +39,35 @@ def bin_interpolation(query: GroupByQuery, result: List[Mapping]) -> List[Mappin
 
 
 def apply_alias_shortening(query: Query) -> Query:
-    if hasattr(query, "groups"):
+    if hasattr(query, "groups") and query.groups:
         for att in query.groups:
             att.switch_to_shortened_alias()
-    if hasattr(query, "aggregations"):
+    if hasattr(query, "aggregations") and query.aggregations:
         for att in query.aggregations:
             att.switch_to_shortened_alias()
+    if hasattr(query, "order_by") and query.order_by:
+        for att in query.order_by:
+            att.switch_to_shortened_alias()
+    if hasattr(query, "attributes") and query.attributes:
+        for att in query.attributes:
+            att.switch_to_shortened_alias()
     return query
 
 
 def restore_original_aliases(query: Query, result: List[Mapping]) -> List[Mapping]:
     alias_map = {}
-    if hasattr(query, "groups"):
+    if hasattr(query, "groups") and query.groups:
         for att in query.groups:
             if att.has_been_shortened():
                 alias_map[att.alias] = att.get_original_alias()
-    if hasattr(query, "aggregations"):
+    if hasattr(query, "aggregations") and query.aggregations:
         for att in query.aggregations:
             if att.has_been_shortened():
                 alias_map[att.alias] = att.get_original_alias()
+    if hasattr(query, "attributes") and query.attributes:
+        for att in query.attributes:
+            if att.has_been_shortened():
+                alias_map[att.alias] = att.get_original_alias()
     if len(alias_map):
         return [{alias_map[k] if k in alias_map else k: v for k, v in row.items()} for row in result]
     return result
